@@ -15,17 +15,20 @@
 set -ex
 
 LRK_DIR=$1
-OUT_TGZ=$2
+shift
+OUT_TGZ=$1
+shift
+CONFIG_ARGS=$*
 
 if [[ ! -f $LRK_DIR/configure.self || -z $OUT_TGZ ]]; then
-    echo "Usage: $0 <librdkafka-root-direcotry> <output-tgz>"
+    echo "Usage: $0 <librdkafka-root-direcotry> <output-tgz> [<configure-args..>]"
     exit 1
 fi
 
 set -u
 
 apt-get update
-apt-get install -y gcc g++ zlib1g-dev python2.7 git-core make
+apt-get install -y gcc g++ zlib1g-dev python3 git-core make
 
 
 # Copy the librdkafka git archive to a new location to avoid messing
@@ -40,10 +43,10 @@ mkdir -p $DEST_DIR
 
 (cd $LRK_DIR ; git archive --format tar HEAD) | tar xf -
 
-./configure --install-deps --disable-gssapi --disable-lz4-ext --enable-static --prefix=$DEST_DIR
+./configure --install-deps --disable-gssapi --disable-lz4-ext --enable-static --prefix=$DEST_DIR $CONFIG_ARGS
 make -j
 examples/rdkafka_example -X builtin.features
-make -C tests run_local
+CI=true make -C tests run_local_quick
 make install
 
 # Tar up the output directory
